from django.shortcuts import render, redirect, get_object_or_404
from django.core.paginator import Paginator
from django.http import HttpResponse
from django.contrib import messages
import pandas as pd
from .models import Customer
from account.models import Account
from django.db import IntegrityError

def customers(request):
    try:
        customers_list = Customer.objects.all()
        paginator = Paginator(customers_list, 10)

        page_number = request.GET.get('page')
        page_obj = paginator.get_page(page_number)

        data = {
            "page_obj": page_obj
        }
        return render(request, "backoffice/customer/customers.html", data)
    except Exception as e:
        messages.error(request, f"An error occurred: {str(e)}")
        return redirect('backoffice:customers')

def add_customer(request):
    if request.method == 'POST':
        try:
            customer_name = request.POST.get('customer_name')
            customer_mobile = request.POST.get('customer_mobile')
            fundi_details = request.POST.get('fundi_details')
            fundi = request.POST.get('fundi')
            added_by_id = request.user.id

            if customer_name and customer_mobile and fundi:
                added_by = Account.objects.get(id=added_by_id) if added_by_id else None
                new_customer = Customer(
                    customer_name=customer_name,
                    customer_mobile=customer_mobile,
                    fundi_details=fundi_details,
                    fundi=fundi,
                    added_by=added_by
                )
                new_customer.save()
                messages.success(request, 'Customer added successfully.')
                return redirect('backoffice:customers')
            else:
                messages.error(request, 'Please fill in all required fields.')
        except IntegrityError as e:
            messages.error(request, f"Data integrity error: {str(e)}")
        except Exception as e:
            messages.error(request, f"An error occurred: {str(e)}")

    return render(request, "backoffice/customer/add_customer.html")

def edit_customer(request, customer_id):
    try:
        customer = get_object_or_404(Customer, id=customer_id)
        if request.method == 'POST':
            customer.customer_name = request.POST.get('customer_name')
            customer.customer_mobile = request.POST.get('customer_mobile')
            customer.fundi_details = request.POST.get('fundi_details')
            customer.fundi = request.POST.get('fundi')

            customer.save()
            messages.success(request, 'Customer updated successfully.')
            return redirect('backoffice:customers')
        return render(request, 'backoffice/customer/edit_customer.html', {'customer': customer})
    except Exception as e:
        messages.error(request, f"An error occurred: {str(e)}")
        return redirect('backoffice:customers')

def delete_customer(request, customer_id):
    try:
        customer = get_object_or_404(Customer, id=customer_id)
        customer_name = customer.customer_name
        customer.delete()
        messages.success(request, f"{customer_name} has been deleted successfully.")
    except Exception as e:
        messages.error(request, f"An error occurred: {str(e)}")
    return redirect('backoffice:customers')